@@ -14,10 +14,9 @@ void ffDetectLocale(FFstrbuf* result)
 
     #ifdef LC_MESSAGES
     ffStrbufAppendS(result, setlocale(LC_MESSAGES, NULL));
-
     if(result->length > 0)
         return;
     #endif
 
-    ffStrbufAppendS(result, setlocale(LC_ALL, NULL));
+    ffStrbufAppendS(result, setlocale(LC_TIME, NULL));
 }
